#include "Adafruit_FreeTouch.h"

#define USE_KEYBOARD

#ifdef USE_KEYBOARD
  #include "Keyboard.h"
#endif

#define PIN_LED 31
#define PIN_QT1 5
#define PIN_QT2 14
#define PIN_QT3 15

#define N_QT 3
#define THRESHOLD 550

char qt_pin[N_QT] = {PIN_QT1, PIN_QT2, PIN_QT3};
bool qt_pressed[N_QT] = {false, false, false};

#ifdef USE_KEYBOARD
char qt_key[N_QT] = {KEY_UP_ARROW, KEY_RIGHT_ARROW, KEY_LEFT_ARROW};
#endif

Adafruit_FreeTouch* qt[N_QT];

bool error = false;

void setup() {
  pinMode(PIN_LED, OUTPUT);

  for (int i = 0; i < N_QT; i++) {
    qt[i] = new Adafruit_FreeTouch(qt_pin[i], OVERSAMPLE_4, RESISTOR_50K, FREQ_MODE_NONE);

    if (!qt[i]->begin()) {
      error = true;
      return;
    }
  }
  #ifdef USE_KEYBOARD
  Keyboard.begin();
  #endif
}

void loop() {
  if (error) {
    return;
  }

  int led_val = LOW;

  for (int i = 0; i < N_QT; i++) {
    int qt_value = qt[i]->measure();

    bool qt_pressed_now = qt_value > THRESHOLD;

    if (qt_pressed_now) {
      led_val = HIGH;
    }

    #ifdef USE_KEYBOARD
    if (qt_pressed_now && !qt_pressed[i]) {
      Keyboard.press(qt_key[i]);
    }
    if (!qt_pressed_now && qt_pressed[i]) {
      Keyboard.release(qt_key[i]);
    }
    #endif

    qt_pressed[i] = qt_pressed_now;
  }

  digitalWrite(PIN_LED, led_val);
}
